# dohq-common

[![build](https://travis-ci.org/devopshq/common.svg)](https://travis-ci.org/devopshq/common)
[![pypi](https://img.shields.io/pypi/v/dohq-common.svg)](https://pypi.python.org/pypi/dohq-common)
[![license](https://img.shields.io/pypi/l/dohq-common.svg)](https://github.com/devopshq/common/blob/master/LICENSE)

**dohq-common** is a common libs package for DevOpsHQ tools

See russian readme here (инструкция на русском здесь): https://github.com/devopshq/common/blob/master/README_RU.md


## Setup

The easiest way is to install via PyPI:
```commandline
pip install dohq-common
```

After that, you can check the installation with the command:
```commandline
pip show dohq-common
```

## Usage examples

***... Will be here soon ...***